struct NoUsableFamilyName;Expand description
An error indicating that the name table contained no usable family names.
For example, this can happen if the family name uses an incompatible or unknown encoding.